==> aql-2.0.0-sources.jar: org/ehrbase/openehr/sdk/aql/dto/condition/ComparisonOperatorCondition.java <==
/*
 * Copyright (c) 2020 vitasystems GmbH and Hannover Medical School.
 *
 * This file is part of project openEHR_SDK
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ehrbase.openehr.sdk.aql.dto.condition;

import org.ehrbase.openehr.sdk.aql.dto.operand.ComparisonLeftOperand;
import org.ehrbase.openehr.sdk.aql.dto.operand.Operand;

public class ComparisonOperatorCondition implements WhereCondition {

    private ComparisonLeftOperand statement;
    private ComparisonOperatorSymbol symbol;
    private Operand value;

    public ComparisonLeftOperand getStatement() {
        return this.statement;
    }

    public ComparisonOperatorSymbol getSymbol() {
        return this.symbol;
    }

    public Operand getValue() {
        return this.value;
    }

    public void setStatement(ComparisonLeftOperand statement) {
        this.statement = statement;
    }

    public void setSymbol(ComparisonOperatorSymbol symbol) {
        this.symbol = symbol;
    }

    public void setValue(Operand value) {
        this.value = value;
    }

    public boolean equals(final Object o) {
        if (o == this) return true;
        if (!(o instanceof ComparisonOperatorCondition)) return false;
        final ComparisonOperatorCondition other = (ComparisonOperatorCondition) o;
        if (!other.canEqual((Object) this)) return false;
        final Object this$statement = this.getStatement();
        final Object other$statement = other.getStatement();
        if (this$statement == null ? other$statement != null : !this$statement.equals(other$statement)) return false;
        final Object this$symbol = this.getSymbol();
        final Object other$symbol = other.getSymbol();
        if (this$symbol == null ? other$symbol != null : !this$symbol.equals(other$symbol)) return false;
        final Object this$value = this.getValue();
        final Object other$value = other.getValue();
        if (this$value == null ? other$value != null : !this$value.equals(other$value)) return false;
        return true;
    }

    protected boolean canEqual(final Object other) {
        return other instanceof ComparisonOperatorCondition;
    }

    public int hashCode() {
        final int PRIME = 59;
        int result = 1;
        final Object $statement = this.getStatement();
        result = result * PRIME + ($statement == null ? 43 : $statement.hashCode());
        final Object $symbol = this.getSymbol();
        result = result * PRIME + ($symbol == null ? 43 : $symbol.hashCode());
        final Object $value = this.getValue();
        result = result * PRIME + ($value == null ? 43 : $value.hashCode());
        return result;
    }

    public String toString() {
        return "ComparisonOperatorCondition(statement="
                + this.getStatement()
                + ", symbol="
                + this.getSymbol()
                + ", value="
                + this.getValue()
                + ")";
    }
}

==> aql-2.4.0-sources.jar: org/ehrbase/openehr/sdk/aql/dto/condition/ComparisonOperatorCondition.java <==
/*
 * Copyright (c) 2020 vitasystems GmbH and Hannover Medical School.
 *
 * This file is part of project openEHR_SDK
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.ehrbase.openehr.sdk.aql.dto.condition;

import java.util.Objects;
import org.ehrbase.openehr.sdk.aql.dto.operand.ComparisonLeftOperand;
import org.ehrbase.openehr.sdk.aql.dto.operand.Operand;

public class ComparisonOperatorCondition implements WhereCondition {

    private ComparisonLeftOperand statement;
    private ComparisonOperatorSymbol symbol;
    private Operand value;

    public ComparisonLeftOperand getStatement() {
        return this.statement;
    }

    public ComparisonOperatorSymbol getSymbol() {
        return this.symbol;
    }

    public Operand getValue() {
        return this.value;
    }

    public void setStatement(ComparisonLeftOperand statement) {
        this.statement = statement;
    }

    public void setSymbol(ComparisonOperatorSymbol symbol) {
        this.symbol = symbol;
    }

    public void setValue(Operand value) {
        this.value = value;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ComparisonOperatorCondition that = (ComparisonOperatorCondition) o;
        return Objects.equals(statement, that.statement) && symbol == that.symbol && Objects.equals(value, that.value);
    }

    @Override
    public int hashCode() {
        return Objects.hash(statement, symbol, value);
    }

    @Override
    public String toString() {
        return "ComparisonOperatorCondition{" + "statement="
                + statement + ", symbol="
                + symbol + ", value="
                + value + '}';
    }
}
